==> tool-sql-2.6.0-sources.jar: io/ciera/tool/sql/architecture/statement/Statement.java <==
package io.ciera.tool.sql.architecture.statement;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.expression.Expression;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.invocable.CodeBlock;
import io.ciera.tool.sql.architecture.statement.BreakSmt;
import io.ciera.tool.sql.architecture.statement.ContinueSmt;
import io.ciera.tool.sql.architecture.statement.DeleteSmt;
import io.ciera.tool.sql.architecture.statement.ExpressionAsStatement;
import io.ciera.tool.sql.architecture.statement.Finalization;
import io.ciera.tool.sql.architecture.statement.FinalizationSet;
import io.ciera.tool.sql.architecture.statement.ForSmt;
import io.ciera.tool.sql.architecture.statement.Generate;
import io.ciera.tool.sql.architecture.statement.Halt;
import io.ciera.tool.sql.architecture.statement.IfSmt;
import io.ciera.tool.sql.architecture.statement.NullSmt;
import io.ciera.tool.sql.architecture.statement.RelateSmt;
import io.ciera.tool.sql.architecture.statement.ReturnSmt;
import io.ciera.tool.sql.architecture.statement.Statement;
import io.ciera.tool.sql.architecture.statement.UnrelateSmt;
import io.ciera.tool.sql.architecture.statement.Variable;
import io.ciera.tool.sql.architecture.statement.VariableSet;
import io.ciera.tool.sql.architecture.statement.WhileSmt;


public interface Statement extends IModelInstance<Statement,Sql> {

    // attributes
    public void setParent_name( String ref_parent_name ) throws XtumlException;
    public String getParent_name() throws XtumlException;
    public void setParent_package( String ref_parent_package ) throws XtumlException;
    public String getParent_package() throws XtumlException;
    public String getBody_name() throws XtumlException;
    public void setBody_name( String ref_body_name ) throws XtumlException;
    public String getBlock_number() throws XtumlException;
    public void setBlock_number( String ref_block_number ) throws XtumlException;
    public void setStatement_number( String m_statement_number ) throws XtumlException;
    public String getStatement_number() throws XtumlException;
    public void setNext_statement_number( String ref_next_statement_number ) throws XtumlException;
    public String getNext_statement_number() throws XtumlException;
    public String getOal() throws XtumlException;
    public void setOal( String m_oal ) throws XtumlException;
    public void setPrefix( String m_prefix ) throws XtumlException;
    public String getPrefix() throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void setR450_is_contained_by_CodeBlock( CodeBlock inst ) {}
    public CodeBlock R450_is_contained_by_CodeBlock() throws XtumlException;
    default public void setR451_is_a_BreakSmt( BreakSmt inst ) {}
    public BreakSmt R451_is_a_BreakSmt() throws XtumlException;
    default public void setR451_is_a_ContinueSmt( ContinueSmt inst ) {}
    public ContinueSmt R451_is_a_ContinueSmt() throws XtumlException;
    default public void setR451_is_a_DeleteSmt( DeleteSmt inst ) {}
    public DeleteSmt R451_is_a_DeleteSmt() throws XtumlException;
    default public void setR451_is_a_ExpressionAsStatement( ExpressionAsStatement inst ) {}
    public ExpressionAsStatement R451_is_a_ExpressionAsStatement() throws XtumlException;
    default public void setR451_is_a_ForSmt( ForSmt inst ) {}
    public ForSmt R451_is_a_ForSmt() throws XtumlException;
    default public void setR451_is_a_Generate( Generate inst ) {}
    public Generate R451_is_a_Generate() throws XtumlException;
    default public void setR451_is_a_Halt( Halt inst ) {}
    public Halt R451_is_a_Halt() throws XtumlException;
    default public void setR451_is_a_IfSmt( IfSmt inst ) {}
    public IfSmt R451_is_a_IfSmt() throws XtumlException;
    default public void setR451_is_a_NullSmt( NullSmt inst ) {}
    public NullSmt R451_is_a_NullSmt() throws XtumlException;
    default public void setR451_is_a_RelateSmt( RelateSmt inst ) {}
    public RelateSmt R451_is_a_RelateSmt() throws XtumlException;
    default public void setR451_is_a_ReturnSmt( ReturnSmt inst ) {}
    public ReturnSmt R451_is_a_ReturnSmt() throws XtumlException;
    default public void setR451_is_a_UnrelateSmt( UnrelateSmt inst ) {}
    public UnrelateSmt R451_is_a_UnrelateSmt() throws XtumlException;
    default public void setR451_is_a_WhileSmt( WhileSmt inst ) {}
    public WhileSmt R451_is_a_WhileSmt() throws XtumlException;
    default public void addR457_declares_Variable( Variable inst ) {}
    default public void removeR457_declares_Variable( Variable inst ) {}
    public VariableSet R457_declares_Variable() throws XtumlException;
    default public void setR477_executes_after_Statement( Statement inst ) {}
    public Statement R477_executes_after_Statement() throws XtumlException;
    default public void setR477_executes_before_Statement( Statement inst ) {}
    public Statement R477_executes_before_Statement() throws XtumlException;
    default public void addR485_finalizes_Finalization( Finalization inst ) {}
    default public void removeR485_finalizes_Finalization( Finalization inst ) {}
    public FinalizationSet R485_finalizes_Finalization() throws XtumlException;
    default public void addR775_may_contain_Expression( Expression inst ) {}
    default public void removeR775_may_contain_Expression( Expression inst ) {}
    public ExpressionSet R775_may_contain_Expression() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/statement/Statement.java <==
package io.ciera.tool.sql.architecture.statement;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.expression.Expression;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.invocable.CodeBlock;
import io.ciera.tool.sql.architecture.statement.BreakSmt;
import io.ciera.tool.sql.architecture.statement.ContinueSmt;
import io.ciera.tool.sql.architecture.statement.DeleteSmt;
import io.ciera.tool.sql.architecture.statement.ExpressionAsStatement;
import io.ciera.tool.sql.architecture.statement.Finalization;
import io.ciera.tool.sql.architecture.statement.FinalizationSet;
import io.ciera.tool.sql.architecture.statement.ForSmt;
import io.ciera.tool.sql.architecture.statement.Generate;
import io.ciera.tool.sql.architecture.statement.Halt;
import io.ciera.tool.sql.architecture.statement.IfSmt;
import io.ciera.tool.sql.architecture.statement.NullSmt;
import io.ciera.tool.sql.architecture.statement.RelateSmt;
import io.ciera.tool.sql.architecture.statement.ReturnSmt;
import io.ciera.tool.sql.architecture.statement.Statement;
import io.ciera.tool.sql.architecture.statement.UnrelateSmt;
import io.ciera.tool.sql.architecture.statement.Variable;
import io.ciera.tool.sql.architecture.statement.VariableSet;
import io.ciera.tool.sql.architecture.statement.WhileSmt;


public interface Statement extends IModelInstance<Statement,Sql> {

    // attributes
    public void setParent_name( String ref_parent_name ) throws XtumlException;
    public String getParent_name() throws XtumlException;
    public String getParent_package() throws XtumlException;
    public void setParent_package( String ref_parent_package ) throws XtumlException;
    public String getBody_name() throws XtumlException;
    public void setBody_name( String ref_body_name ) throws XtumlException;
    public String getBlock_number() throws XtumlException;
    public void setBlock_number( String ref_block_number ) throws XtumlException;
    public void setStatement_number( String m_statement_number ) throws XtumlException;
    public String getStatement_number() throws XtumlException;
    public String getNext_statement_number() throws XtumlException;
    public void setNext_statement_number( String ref_next_statement_number ) throws XtumlException;
    public String getActions() throws XtumlException;
    public void setActions( String m_actions ) throws XtumlException;
    public void setPrefix( String m_prefix ) throws XtumlException;
    public String getPrefix() throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void setR450_is_contained_by_CodeBlock( CodeBlock inst ) {}
    public CodeBlock R450_is_contained_by_CodeBlock() throws XtumlException;
    default public void setR451_is_a_BreakSmt( BreakSmt inst ) {}
    public BreakSmt R451_is_a_BreakSmt() throws XtumlException;
    default public void setR451_is_a_ContinueSmt( ContinueSmt inst ) {}
    public ContinueSmt R451_is_a_ContinueSmt() throws XtumlException;
    default public void setR451_is_a_DeleteSmt( DeleteSmt inst ) {}
    public DeleteSmt R451_is_a_DeleteSmt() throws XtumlException;
    default public void setR451_is_a_ExpressionAsStatement( ExpressionAsStatement inst ) {}
    public ExpressionAsStatement R451_is_a_ExpressionAsStatement() throws XtumlException;
    default public void setR451_is_a_ForSmt( ForSmt inst ) {}
    public ForSmt R451_is_a_ForSmt() throws XtumlException;
    default public void setR451_is_a_Generate( Generate inst ) {}
    public Generate R451_is_a_Generate() throws XtumlException;
    default public void setR451_is_a_Halt( Halt inst ) {}
    public Halt R451_is_a_Halt() throws XtumlException;
    default public void setR451_is_a_IfSmt( IfSmt inst ) {}
    public IfSmt R451_is_a_IfSmt() throws XtumlException;
    default public void setR451_is_a_NullSmt( NullSmt inst ) {}
    public NullSmt R451_is_a_NullSmt() throws XtumlException;
    default public void setR451_is_a_RelateSmt( RelateSmt inst ) {}
    public RelateSmt R451_is_a_RelateSmt() throws XtumlException;
    default public void setR451_is_a_ReturnSmt( ReturnSmt inst ) {}
    public ReturnSmt R451_is_a_ReturnSmt() throws XtumlException;
    default public void setR451_is_a_UnrelateSmt( UnrelateSmt inst ) {}
    public UnrelateSmt R451_is_a_UnrelateSmt() throws XtumlException;
    default public void setR451_is_a_WhileSmt( WhileSmt inst ) {}
    public WhileSmt R451_is_a_WhileSmt() throws XtumlException;
    default public void addR457_declares_Variable( Variable inst ) {}
    default public void removeR457_declares_Variable( Variable inst ) {}
    public VariableSet R457_declares_Variable() throws XtumlException;
    default public void setR477_executes_after_Statement( Statement inst ) {}
    public Statement R477_executes_after_Statement() throws XtumlException;
    default public void setR477_executes_before_Statement( Statement inst ) {}
    public Statement R477_executes_before_Statement() throws XtumlException;
    default public void addR485_finalizes_Finalization( Finalization inst ) {}
    default public void removeR485_finalizes_Finalization( Finalization inst ) {}
    public FinalizationSet R485_finalizes_Finalization() throws XtumlException;
    default public void addR775_may_contain_Expression( Expression inst ) {}
    default public void removeR775_may_contain_Expression( Expression inst ) {}
    public ExpressionSet R775_may_contain_Expression() throws XtumlException;


}
